function [cod_all, tod] = ampc_plot_fig_2(mp_all)
global q;
q = 0;
%% Initialize parameters
if ~exist('out_p', 'var')
    out_p = [mp_all '/Fig/'];
end
mp = [mp_all 'OD/robo_fig2/'];
th = 0.1; l = lines(7);
l(5,:) = [0 0 0]; l(6,:) = [0.5 0.5 0.5];

%% analyse OD data
od_data = ana_od(mp);
%% prepare the axes of figures;
figure('Position', [100 100 420 500]);
ax = open_axes;
%% plot Ni of bacteria VS conc.
cod_all = plot_ODi(od_data, th, ax,l);
%% add general xlabel
ax_yl = axes('position', [0.065 0 0.5 0.65]);
text(0,  0.6, 'Expected initial density of resistant\newline     mutants, {\itOD^0_{Res} = OD_{th}\cdote^{-g\cdott_{th}}}', ...
    'Rotation', 90, 'HorizontalAlignment', 'center', 'FontSize', 10)
ax_yl.Visible = 'off';
%% plot growth curves of PIP
axes(ax(5));
tod = plot_growth_curves (ax(5), od_data(1), 2, th, 13);
%% add legend for conc
axes(ax(6));
cla;
for i = 1:numel(od_data(1).conc)
    if i~=13
    semilogy([1 2], [od_data(1).conc(i) od_data(1).conc(i)], 'linewidth', 2, 'color', (1/20*(20-i)) * [1 1 1]); hold on;
    end
end
l3 = lines;
semilogy([1 2], [od_data(1).conc(13) od_data(1).conc(13)], 'linewidth', 3, 'color', l3(6,:));

ylim([ od_data(1).conc(1)/1.2 od_data(1).conc(end)*1.2])
xlim([1 3]);
text(2.2, 1, '10^0', 'fontsize', 8);
text(2.2, 10, '10^1', 'fontsize', 8);
text(2.2, 100, '10^2', 'fontsize', 8);
text(3.4, 15, '[PIP] \mug/ml', 'Rotation', 90, 'HorizontalAlignment', 'center')
ax(6).Visible = 'off';
%% print figure
if ~exist(out_p, 'dir'); mkdir(out_p); end
print([out_p 'fig2'], '-dpng', '-r600');
print([out_p 'fig2'], '-depsc', '-painters');
end
function od_data = ana_od(mp)

data_path = [mp 'data/'];
xls_name = dir([mp '*.xlsx']);
[ab_names, concs, plates] = ampc_import_conc([xls_name.folder '/' xls_name.name]);

file_names = dir([data_path '*.xml']);
plate_names = cellfun(@(x) str2num(x{1}{1}), (regexp({file_names.name}, '(^\d.?)-', 'tokens')));
t0 = datevec(file_names(1).datenum);



for i = numel(plates):-1:1
    raw_data(i).ab = struct('name', ab_names);
    for k = numel(ab_names):-1:1
        ab_ind = find(concs{i}(:,k)>0);
        [raw_data(i).ab(k).conc, s] = sort(concs{i}(ab_ind,k));
        s_ab_ind{k} = ab_ind(s);
    end
    rel_p = find(plate_names == plates(i));
    raw_data(i).t = zeros(numel(rel_p),1);
    for j = 1:numel(rel_p)
        raw_data(i).t(j) = etime(datevec(file_names(rel_p(j)).datenum),t0)/60;
        od2 = d300_xml_parse([data_path file_names(rel_p(j)).name]);
        if ~mod(j,2)
            od2 = od2(end:-1:1, end:-1:1);
        end
        od = od2(:)';
        for k = 1:numel(ab_names)
            raw_data(i).ab(k).od(j,:) = od(s_ab_ind{k});
        end
    end
end

v = [2:5; 6:9];
strains = {'WT' 'MAGE' 'WT+AVI', 'MAGE+AVI'};

od_data = struct('name', {raw_data(1).ab.name}, 'conc', {raw_data(1).ab.conc});
for i = 1:numel(od_data)
    for j = 1:numel(strains)
        od_data(i).strains(j).name = strains{j};
        od_data(i).strains(j).od = cat(3, raw_data(v(1,j)).ab(i).od, raw_data(v(2,j)).ab(i).od);
        od_data(i).strains(j).t = cat(3, raw_data(v(1,j)).t, raw_data(v(2,j)).t);
    end
end
od_data = od_data([2:4 1]);
end
function cod_all = plot_ODi(od_data, th, ax, l)

% ploting the curves
lt = {'-' '-' ':' ':'};
l2 = l([5 6 5 6], :);
for i = 1:numel(od_data)
    axes(ax(i));
    cod_all(i) = plot_Ni_bact_from_od (od_data(i), ax(i), th);
    ylim(ax(i), [1e-9 1e-1]);
    if any(i == [1 4])
        set(ax(i), 'ytick', 10.^([-9 -5 -1])); 
    else
        set(ax(i), 'ytick', []);    
    end
end

% add legend
axl = axes('Position', [0.76 0.23 0.18 0.08]);
for i = 1:4
    plot(1:2, [i i], lt{i}, 'color', l2(i,:),'linewidth', 2); hold on;
    plot(1.5, i, 'o', 'Color', l2(i,:), 'MarkerFaceColor', 1-(i<3)*(1-l2(i,:)), 'markersize', 4);
    text(2.5, i, od_data(1).strains(i).name, 'FontSize', 8);
end
xlim([1 5])
axl.Visible = 'off';
axl.YDir = 'reverse';
    function cod = plot_Ni_bact_from_od (od_data, ah, th)
        %
        th_single = 0.6e-7;
        for j = 1:numel(od_data.strains)
            clear t_th t_th_rep;
            t = (od_data.strains(j).t(1:end-1,:,:)+od_data.strains(j).t(2:end,:,:))/2;
            od1 = od_data.strains(j).od-0.042; od1(od1<0) = 0;
            od = (od1(1:end-1,:,:) + od1(2:end,:,:))/2;
            
            for ci = size(od,2):-1:1
                rel_od = squeeze(od(:,ci,:)); rel_od(rel_od<1e-4) = 1e-4;
                rel_t = squeeze(t);
                for rep = 2:-1:1
                    i0 = find(smooth(rel_od(:,rep)-th<0,4), 1, 'last');
                    ind = i0-2:min(i0+1, size(rel_od,1));
                    t_th_rep(ci,rep) = interp1(rel_od(ind,rep)+rand(size(ind'))*1e-5, rel_t(ind,rep), th);
                end
                i0 = find(smooth(mean(rel_od,2)-th<0,4), 1, 'last');
                ind = i0-2:min(i0+1, size(rel_od,1));
                t_th(ci) = interp1(mean(rel_od(ind,:),2)+rand(size(ind'))*1e-5 , mean(rel_t(ind,:),2) , th);
            end
            %% fit to 2 stairs:
            th_rep_s = sort(t_th_rep,2);
            x2(j) = od_data.conc(find( any(th*2.^(-0.026*th_rep_s)>1e-10, 2), 1, 'last'));
            
            ind_nan = ~any(isnan(t_th_rep),2);
            if sum(ind_nan)>6
                ft = fittype('-((15 * b)./(1+(c./x).^d) + (15*(1-b))./(1+(e./x).^f)+6)');
                ic0_1 = od_data.conc(find(th*2.^(-0.026*t_th) < 0.01 * th*2.^(-0.026*t_th(1)),1));
                ic0_2 = od_data.conc(find(th*2.^(-0.026*t_th) < 0.001 * th*2.^(-0.026*t_th(1)),1));
                fo = fitoptions(ft);
                fo.Startpoint = [0.5, ic0_1, 1, ic0_2, 1];
                fo.Lower = [0, 0, 0, 0, 0];
                fo.Upper = [1, inf, 20, inf, 20];
                f = fit(repmat(od_data.conc(ind_nan),2,1), ...
                    log(th*2.^(-0.026* reshape(t_th_rep(ind_nan,:), [],1) )), ft, fo);                

                xax = logspace(log10(od_data.conc(find(ind_nan,1))), log10(od_data.conc(find(ind_nan,1, 'last'))), 1000);
                loglog(xax, exp(f(xax)) ...
                    , lt{j}, 'Color', l2(j,:), 'LineWidth',2); hold on;
            else
                loglog(ah, od_data.conc, th*2.^(-0.026*t_th), lt{j}, 'Color', l2(j,:), 'LineWidth',2); hold on;
                f = fit(od_data.conc(~isnan(t_th)), log(th*2.^(-0.026*(t_th(~isnan(t_th))))'), 'linearinterp');
            end
            ct(j) = fzero(@(x) exp(f(x))-th_single, [od_data.conc(1) od_data.conc(find(ind_nan,1,'last'))]);
            cod.conc = od_data.conc;
            cod.Ni = (th*2.^(-0.026*th_rep_s));
            cod.ab = od_data.name;
            global q;
            q = q+1;
            plot( od_data.conc, (th*2.^(-0.026*th_rep_s)), 'o', 'Color', l2(j,:), 'MarkerFaceColor', 1-(j<3)*(1-l2(j,:)), 'markersize', 3);
            if i == 1 && j == 2
                l3 = lines;
                plot( od_data.conc(13), (th*2.^(-0.026*th_rep_s(13))), 'o', 'Color', l3(6,:), 'markerfacecolor', l3(6,:), 'markersize', 4);
            end
        end
        
        xl = xlim;
        xlim([max(xl(1), od_data.conc(1)/1.1) max(x2)]);
        plot(xlim, [th_single th_single], '--k');
        xl = xlim;
        
        if i == 1 || i == 4
            text(xl(1)*0.95, th_single, 'Single\newlinemutant', ... 'Rotation', 90, ...
                'HorizontalAlignment', 'right', 'FontSize', 7);
        end
        
        ylim([1e-9 0.01])
        yl = ylim;
        set(ah, 'XTick', []);
        p = ah.Position;
        p(2) = p(2)-0.03; p(4) = 0.01;
        ah2 = axes('Position', p);        
        axes(ah2); hold on;
        for j = 1:numel(od_data.strains)
            plot(ah, [ct(j) ct(j)], [1e-10 th_single], ':', 'Color', l2(j,:));
            plot(ah2, ct(j), 0.5 , '^', 'Color', l2(j,:), 'MarkerFaceColor', 1-(j<3)*(1-l2(j,:)), 'markersize', 7, 'linewidth', 2)
        end
        set(ah2, 'YColor', 'none', 'XLim', xl, 'XTick', 10.^(-2:2),'XScale', 'log', 'ylim', [0 1], 'box', 'off');
        xlabel(['[' od_data.name '] \mug/ml'])        
        draw_arrow(ah2, [ct(1), ct(4)], [1.7, 1.7], l(4,:));
    end
end
function tod = plot_growth_curves (ah, od_data, st, th, rel_c)
l = lines(7);
t = (od_data.strains(st).t(1:end-1,:,1)+od_data.strains(st).t(2:end,:,1))/2 /60;
od1 = od_data.strains(st).od(:,:,1)-0.0425;

od = (od1(1:end-1,:) + od1(2:end,:))/2;
od(od<10^(-2.5)) = 0;
tod.t = t;
tod.od = od;

%%
for i = 1:size(od,2)
    semilogy(ah, t, od(:,i), 'linewidth', 1.5, 'color', (1/20*(20-i)) * [1 1 1]); hold on;
end
%%
set(ah, 'xlim', [0 t(end)]);
plot(ah, t, od(:, rel_c), '-', 'linewidth', 3, 'color', l(6,:));
hold on; plot(xlim, [th th], '--', 'linewidth', 2, 'color', l(2,:));
xlabel(ah, 'Time (Hours)');
ylabel(ah, 'Optical density, OD', 'FontSize', 10);

mt = interp1(od(:, rel_c)+rand(size(od,1),1)*1e-5, t, th);
ODi = th/2^(mt*1.56);

ylim([10^(-2.5) 1]);
yl = ylim;

plot([mt mt], [yl(1) th], '--', 'color', l(6,:));
text(mt+0.35, 0.002, 't_{th}', 'Color', l(6,:), 'FontSize', 10);
text(0.3, th*1.1, 'OD_{th}', 'Color', l(2,:), 'FontSize', 9, ...
    'HorizontalAlignment', 'left', 'VerticalAlignment', 'bottom');

end

function ax = open_axes
ax(4) = axes('Position', [0.2 0.13 0.37 0.20]);
ax(3) = axes('Position', [0.61 0.13 0.37 0.20]);
ax(1) = axes('Position', [0.2 0.46 0.37 0.20]);
annotation('textbox', [0.05 0.66 0.01 0.01], 'String', 'b', 'FontSize', 14, ...
    'EdgeColor', 'none', 'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle');
ax(2) = axes('Position', [0.61 0.46 0.37 0.20]);
ax(5) = axes('Position', [0.2 0.76 0.55 0.22]);
annotation('textbox', [0.05 0.96 0.01 0.01], 'String', 'a', 'FontSize', 14, ...
    'EdgeColor', 'none', 'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle');
ax(6) = axes('Position', [0.77 0.76 0.1 0.22]);
end