function ampc_plot_fig_3(mp_all, out_p)
% initializing the paths
if ~exist('out_p', 'var')
    out_p = [mp_all '/Fig/'];
end
mp = [mp_all 'Results/'];
mp_im = [mp_all 'Structures/'];

% open the axes for the single drug IC plot
ax = open_axes();
% load mage dataset and arange it
mage = load_mage(mp);
% plot the single drug mic's
plot_single_drug(mage, ax);
% plot the pairwise cross resistance
plot_pair_wise_drug_inter(mage, ax)
% add the 3d structures
add_3d_struct(mp_im, ax(7:9))
% add annotation
anot_fig3;

% save the figure;
if ~exist(out_p, 'dir'); mkdir(out_p); end
print([out_p 'fig3'], '-dpng', '-r600');
print([out_p 'fig3'], '-depsc', '-painters');
end

%% internal functions

function ax = open_axes
figure('Position', [100 100 700 800]);
ax(1) = axes('Position', [0.125 0.3 0.4 0.21]); % pip single
ax(3) = axes('Position', [0.125 0.52 0.4 0.21]); % atm single
ax(5) = axes('Position', [0.125 0.74 0.4 0.21]); % fep single
ax(2) = axes('Position', [0.095 0.07 0.2 0.17]); % pip-atm
ax(4) = axes('Position', [0.425 0.07 0.2 0.17]); % pip-fep
ax(6) = axes('Position', [0.755 0.07 0.2 0.17]); % atm-fep
ax(7) = axes('Position', [0.55 0.31 0.45 0.19]); % 3d pip
ax(8) = axes('Position', [0.55 0.53 0.45 0.19]); % 3d atm
ax(9) = axes('Position', [0.55 0.75 0.45 0.19]); % 3d cfp
end

function mage = load_mage(mp)
% loading the original mage struct
tmp = load([mp 'data_s2p2.mat'], 'mage');
mage_old(2) = tmp.mage;
tmp = load([mp 'data_s2p1.mat'], 'mage');
mage_old(1) = tmp.mage;
load([ mp 'IC_struct']);

% constructing the mage IC_struct
mage.IC_struct = IC_struct;
mage.IC_mat = [IC_struct(1).IC_mat(1:end-1,:); IC_struct(2).IC_mat(1:end-1,:)];
mage.IC_wt = IC_struct(1).IC_mat(end,:);
mage.pos = [IC_struct(1).Pos(1:end-1); IC_struct(2).Pos(1:end-1)];
mage.mut_aa = [IC_struct(1).aa(1:end-1); IC_struct(2).aa(1:end-1)];

rel_pos = unique(cellfun(@(x) str2num(x(2:end)), mage.pos));
mage.orig_codon = [mage_old(1).orig_codons(any(mage_old(1).Pos == rel_pos'+16,2),:)
    mage_old(2).orig_codons(any(mage_old(2).Pos == rel_pos'+16,2),:)];
mage.all_aa = mage_old(1).aa';
mage.u_pos = unique(mage.pos, 'stable');
end

function plot_single_drug(mage, ax)
% loading the genetic code
map = geneticcode;
map = rmfield(map, 'Name');
map = rmfield(map, 'Starts');
codons = fieldnames(map);
cog_aa = struct2array(map);
an = 'ACGT';
% identifying the relevant residues
npos = numel(mage.u_pos);
naa = numel(mage.all_aa);

%identify the WT aa for each residue and the null positions (ones that was
%not created)
n_pos = numel(mage.u_pos);
wt_pos = zeros(npos,2);
null_pos = [];
for j = 1:n_pos
    wt_pos(j,:) = [find(ismember(mage.all_aa, mage.u_pos{j}(1))), j];
    rc = mage.orig_codon(j,:);
    pos_cod1 = ~cellfun(@isempty, regexp(codons, sprintf('[%s][%s][%s]', an(an~=rc(1)), an, an(an~=rc(3)))));
    pos_cod2 = ~cellfun(@isempty, regexp(codons, sprintf('[%s][%s][%s]', an, an(an~=rc(2)), an(an~=rc(3)))));
    tmp = ~any([any((mage.all_aa-cog_aa(pos_cod1))==0,2) any((mage.all_aa-cog_aa(pos_cod2))==0,2)],2);
    tmp(wt_pos(j,1)) = 0;
    not_acce_aa = find(tmp);
    null_pos = [null_pos; not_acce_aa repmat(j, numel(not_acce_aa),1)];
end


not_rep = [];
for i = 1:2:5
    %%
    mat_IC = zeros(naa, npos);
    for p = 1:npos
        rel_p = mage.u_pos(p);
        ind = ismember(mage.pos, rel_p);
        for aa = 1:naa
            
            rel_mut = ismember(mage.mut_aa,mage.all_aa(aa)) & ind;
            if any(rel_mut)
                mat_IC(aa,p) = log2(mage.IC_mat(rel_mut ,i)/mage.IC_wt(i));
            else
                % identify mutants that was not enriched in the data
                not_rep = [not_rep; aa p];
            end
            
        end
    end    
    %% ploting the data
    axes(ax(i));
    m = max(abs((mat_IC(:))));
    imagesc((mat_IC), [-3 3]); colormap(redbluecmap); hold on;
    
    plot(wt_pos(:,2), wt_pos(:,1), 'xk', 'linewidth', 1, 'markersize', 5);
    plot(not_rep(:,2), not_rep(:,1), '.k', 'markersize', 2);
    for n = 1:size(null_pos)
        rectangle('Position', [null_pos(n,2)-0.5, null_pos(n,1)-0.5 1 1], 'FaceColor', [0.7 0.7 0.7], 'EdgeColor', 'none')
    end
    
    set(ax(i), 'YAxisLocation', 'right');
    
    hcb(i) = colorbar('Position', [0.09 ax(i).Position(2) 0.03 0.21]);
    hcb(i).Label.String = ['  Resistance,\newline' ...
        'IC50^{Mut}_{' mage.IC_struct(1).ab(i).Name '}/IC50^{WT}_{' mage.IC_struct(1).ab(i).Name '}'];
    hcb(i).Label.FontName = 'SansSerif';
    hcb(i).Ticks = [-2.7 -2:2 2.7];
    hcb(i).TickLabels = {'1/8' '1/4' '1/2' '1' '2' '4' '>8'};
    
    hcb(i).FontSize = 7;
    hcb(i).Label.FontSize = 8;

    %%
    for j = 1:21
        if mod(j,2)
            a{j} = ['' mage.all_aa(j)];
        else
            a{j} = [mage.all_aa(j) ''];
        end
    end
    %%
    if i == 1
        set(ax(i), 'XTick', 1:npos, 'XTickLabel', mage.u_pos, 'XTickLabelRotation', 90, ...
            'FontName', 'Courier' ,'YTick', 1:naa, 'YTickLabel', a, 'FontSize', 7);
    else
        set(ax(i), 'XTick', [], 'FontName', 'Courier' ,'YTick', 1:naa, 'YTickLabel', a, 'FontSize', 7);
    end
    text(-4.5, 3, mage.IC_struct(1).ab(i).Name, 'fontsize', 10);
end

ax(7) = axes('Position', [ax(1).Position(1) ax(1).Position(2)-0.045 ax(1).Position(3) 0.01]);

[col,symb] = ampc_markers;
d = gscatter(1:numel(mage.u_pos), ones(numel(mage.u_pos),1)*0.5, 1:numel(mage.u_pos), col, symb, 5, 'off');
xlim([0.5 0.5+numel(mage.u_pos)]);
ax(7).Visible = 'off';
end

function plot_pair_wise_drug_inter(mage, ax)
i = [1 1 3];
j = [3 5 5];
[col,symb] = ampc_markers;

for k = 1:3
    axes(ax(k*2));
    xl = [min(mage.IC_mat(:,i(k)))*0.8 max(mage.IC_mat(:,i(k)))*1.25]; %xlim(xl);
    yl = [min(mage.IC_mat(:,j(k)))*0.8 max(mage.IC_mat(:,j(k)))*1.25]; %ylim(yl);
    
    x = mage.IC_wt(i(k));
    y = mage.IC_wt(j(k));
    %%
    patch([xl(1)*1.02 xl(1)*1.02 xl(2) xl(2)], ...
        [ y/1.5 y*1.5 y*1.5 y/1.5], [0.9 0.9 0.9], ...
        'edgecolor', [1 1 1 ], 'edgealpha', 0); hold on;
    patch([ x/1.5 x*1.5 x*1.5 x/1.5], ...
        [yl(1)*1.02 yl(1)*1.02 yl(2) yl(2)],[0.9 0.9 0.9], ...
        'edgecolor', [1 1 1 ], 'edgealpha', 0);
    %%
    
    d = gscatter(mage.IC_mat(:,i(k)), mage.IC_mat(:,j(k)),mage.pos, col, symb, 6, 'off');
    hold on;
    plot(x, y, 'xk', 'markersize', 10, 'LineWidth', 2);
    
    
    plot(xl, [y y], 'k--', 'linewidth', 1);
    plot([x x], yl, 'k--', 'linewidth', 1);
    xlabel(['IC50_{' mage.IC_struct(1).ab(i(k)).Name '}^{Mut} (\mug/ml)']);
    set(ax(k*2), 'XTick', 10.^(-2:2), 'YTick', 10.^(-2:2), 'xscale', 'log',...
        'yscale', 'log', 'XMinorTick', 'on', 'YMinorTick', 'on', 'Box', 'on');
    
    ylabel(['IC50_{' mage.IC_struct(1).ab(j(k)).Name '}^{Mut} (\mug/ml)']);
    
    xlim(xl)
    ylim(yl)
end
end

function add_3d_struct(mp, ax)
names = {'PIP' 'ATM' 'FEP'};
for i = 1:3
    f = dir([mp '*' names{i} '_RIBBON.png']);
    im = imread([mp f.name]);
    axes(ax(i));
    imshow(im);
    
end
end

function anot_fig3()
%%
t = annotation('textbox', [0.04 0.95 0.001 0.001], 'String', 'a', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle', ...
    'FontSize', 14, 'EdgeColor', 'none');

t = annotation('textbox', [0.57 0.95 0.001 0.001], 'String', 'c', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle', ...
    'FontSize', 14, 'EdgeColor', 'none');

t = annotation('textbox', [0.04 0.25 0.001 0.001], 'String', 'b', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle', ...
    'FontSize', 14, 'EdgeColor', 'none');
%%
end