function ampc_plot_fig_4(mp_all, out_p)
% initializing the paths
if ~exist('out_p', 'var')
    out_p = [mp_all 'Fig/'];
end
mp = [mp_all 'Results/'];

% open the axes for the single drug IC plot
ax = open_axes();
% load mage dataset and arange it
mage = load_mage(mp);
% plot the single drug mic's
plot_single_drug(mage, ax);

% save the figure;
print([out_p 'fig4'], '-dpng', '-r600');
print([out_p 'fig4'], '-depsc', '-painters');
end

%% internal functions

function ax = open_axes
figure('Position', [100 100 400 600]);
ax(2) = axes('Position', [0.25 0.08 0.7 0.27]); % pip single
ax(4) = axes('Position', [0.25 0.39 0.7 0.27]); % atm single
ax(6) = axes('Position', [0.25 0.7 0.7 0.27]); % cfp single
end

function mage = load_mage(mp)
% loading the original mage struct
tmp = load([mp 'data_s2p2.mat'], 'mage');
mage_old(2) = tmp.mage;
tmp = load([mp 'data_s2p1.mat'], 'mage');
mage_old(1) = tmp.mage;
load([ mp 'IC_struct']);

% constructing the mage IC_struct
mage.IC_struct = IC_struct;
mage.IC_mat = [IC_struct(1).IC_mat(1:end-1,:); IC_struct(2).IC_mat(1:end-1,:)];
mage.IC_wt = IC_struct(1).IC_mat(end,:);
mage.pos = [IC_struct(1).Pos(1:end-1); IC_struct(2).Pos(1:end-1)];
mage.mut_aa = [IC_struct(1).aa(1:end-1); IC_struct(2).aa(1:end-1)];

rel_pos = unique(cellfun(@(x) str2num(x(2:end)), mage.pos));
mage.orig_codon = [mage_old(1).orig_codons(any(mage_old(1).Pos == rel_pos'+16,2),:)
    mage_old(2).orig_codons(any(mage_old(2).Pos == rel_pos'+16,2),:)];
mage.all_aa = mage_old(1).aa';
mage.u_pos = unique(mage.pos, 'stable');
end


function plot_single_drug(mage, ax)
% loading the genetic code
map = geneticcode;
map = rmfield(map, 'Name');
map = rmfield(map, 'Starts');
codons = fieldnames(map);
cog_aa = struct2array(map);
an = 'ACGT';
% identifying the relevant residues
npos = numel(mage.u_pos);
naa = numel(mage.all_aa);

%identify the WT aa for each residue and the null positions (ones that was
%not created)
n_pos = numel(mage.u_pos);
wt_pos = zeros(npos,2);
null_pos = [];
for j = 1:n_pos
    wt_pos(j,:) = [find(ismember(mage.all_aa, mage.u_pos{j}(1))), j];
    rc = mage.orig_codon(j,:);
    pos_cod1 = ~cellfun(@isempty, regexp(codons, sprintf('[%s][%s][%s]', an(an~=rc(1)), an, an(an~=rc(3)))));
    pos_cod2 = ~cellfun(@isempty, regexp(codons, sprintf('[%s][%s][%s]', an, an(an~=rc(2)), an(an~=rc(3)))));
    tmp = ~any([any((mage.all_aa-cog_aa(pos_cod1))==0,2) any((mage.all_aa-cog_aa(pos_cod2))==0,2)],2);
    tmp(wt_pos(j,1)) = 0;
    not_acce_aa = find(tmp);
    null_pos = [null_pos; not_acce_aa repmat(j, numel(not_acce_aa),1)];
end

not_rep = [];
for i = 2:2:6
    %%
    mat_IC = zeros(naa, npos);
    for p = 1:npos
        rel_p = mage.u_pos(p);
        ind = ismember(mage.pos, rel_p);
        for aa = 1:naa
            
            rel_mut = ismember(mage.mut_aa,mage.all_aa(aa)) & ind;
            if any(rel_mut)
                mat_IC(aa,p) = log2(mage.IC_mat(rel_mut ,i)/mage.IC_wt(i));
            else
                % identify mutants that was not enriched in the data
                not_rep = [not_rep; aa p];
            end
            
        end
    end
    %%
    % delete the WT from the mut not created
    [xx,yy] = meshgrid(mat2cell(null_pos,ones(size(null_pos,1),1), 2), mat2cell(wt_pos,ones(size(wt_pos,1),1), 2)');
    null_pos(any(cellfun(@(x,y) all(x == y), xx, yy),1),:) = [];
    
    %% ploting the data
    axes(ax(i));
    m = max(abs((mat_IC(:))));
    imagesc((mat_IC), [-3 3]); colormap(redbluecmap); hold on;
    
    plot(wt_pos(:,2), wt_pos(:,1), 'xk', 'linewidth', 1, 'markersize', 5);
    plot(not_rep(:,2), not_rep(:,1), '.k', 'markersize', 2);
    for n = 1:size(null_pos)
        rectangle('Position', [null_pos(n,2)-0.5, null_pos(n,1)-0.5 1 1], 'FaceColor', [0.7 0.7 0.7], 'edgecolor', 'none')
    end
    
    set(ax(i), 'YAxisLocation', 'right');
    
    hcb(i) = colorbar('Position', [0.2 ax(i).Position(2) 0.03 ax(i).Position(4)]);
    name = mage.IC_struct(1).ab(i-1).Name;
    hcb(i).Label.String = ['        Resistance,\newlineIC50^{Mut}_{' ...
        name '}|^{AVI}/IC50^{WT}_{' name '}|^{AVI}'];
    hcb(i).Label.FontName = 'SansSerif';
    hcb(i).Ticks = [-2.7 -2:2 2.7];
    hcb(i).TickLabels = {'1/8' '1/4' '1/2' '1' '2' '4' '>8'};
    
    hcb(i).FontSize = 7;
    hcb(i).Label.FontSize = 8;

    %%
    for j = 1:21
        if mod(j,2)
            a{j} = ['' mage.all_aa(j)];
        else
            a{j} = [mage.all_aa(j) ''];
        end
    end
    %%
    if i == 2
        set(ax(i), 'XTick', 1:npos, 'XTickLabel', mage.u_pos, 'XTickLabelRotation', 90, ...
            'FontName', 'Courier' ,'YTick', 1:naa, 'YTickLabel', a, 'FontSize', 7);
    else
        set(ax(i), 'XTick', [], 'FontName', 'Courier' ,'YTick', 1:naa, 'YTickLabel', a, 'FontSize', 7);
    end
    text(-6, 1, mage.IC_struct(1).ab(i).Name, 'fontsize', 10);
end

ax(7) = axes('Position', [ax(2).Position(1) ax(2).Position(2)-0.055 ax(2).Position(3) 0.01]);

[col,symb] = ampc_markers;
d = gscatter(1:numel(mage.u_pos), ones(numel(mage.u_pos),1)*0.5, 1:numel(mage.u_pos), col, symb, 5, 'off');
xlim([0.5 0.5+numel(mage.u_pos)]);
ax(7).Visible = 'off';
end