function ampc_plot_fig_5(mp_all, out_p)
if ~exist('out_p', 'var')
    out_p = [mp_all '/Fig/'];
end

mp = [mp_all 'Results/'];
mp_new_ab = [mp_all 'OD/robo_fig4/190619_Add_AB/'];
% open the axes for the single drug IC plot
ax = open_axes();
% load mage dataset and arange it
mage = load_mage(mp);

if 1
% plot the single drug mic's
plot_AB_AVI(mage, ax);
% plot the scheme of the treatment japordizers
plot_schematics(ax(4));
% plot the legend
plot_legend(mage.u_pos, ax(5))
% add 2d plots
od_data2d = ampc_calc_2d(mp_all);
plot_2d_AVI(od_data2d(2), ax(6));
plot_2d_AVI(od_data2d(1), ax(7));

% add additional AB
plot_add_ab(mp_new_ab, ax(8));

if ~exist(out_p, 'dir'); mkdir(out_p); end
print([out_p 'fig4'], '-dpng', '-r600');
print([out_p 'fig5'], '-depsc', '-painters');
end
end
%% functions

function ax = open_axes
figure('Position', [100 100 580 650]);
i = 0;
i = i+1; ax(i) = axes('Position', [0.54 0.74 0.27 0.235]); % PIP-AVI
xa = ax(i).Position(1) -0.07; ya = ax(i).Position(2) + ax(i).Position(4)-0.01;
annotation('textbox', [xa ya 0.01 0.01],'string', 'b', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle', ...
    'EdgeColor', 'none', 'FontSize', 14);

i = i+1; ax(i) = axes('Position', [0.1 0.39 0.27 0.235]); % AZT-AVI
xa = ax(i).Position(1) -0.07; ya = ax(i).Position(2) + ax(i).Position(4)-0.01;
annotation('textbox', [xa ya 0.01 0.01],'string', 'c', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle', ...
    'EdgeColor', 'none', 'FontSize', 14);

i = i+1; ax(i) = axes('Position', [0.54 0.39 0.27 0.235]); % CFP-AVI
xa = ax(i).Position(1) -0.07; ya = ax(i).Position(2) + ax(i).Position(4)-0.01;
annotation('textbox', [xa ya 0.01 0.01],'string', 'd', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle', ...
    'EdgeColor', 'none', 'FontSize', 14);

i = i+1; ax(i) = axes('Position', [0.1 0.74 0.27 0.235]); % schematics
xa = ax(i).Position(1) -0.07; ya = ax(i).Position(2) + ax(i).Position(4)-0.01;
annotation('textbox', [xa ya 0.01 0.01],'string', 'a', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle', ...
    'EdgeColor', 'none', 'FontSize', 14);

i = i+1; ax(i) = axes('Position', [0.87 0.5 0.12 0.47]); % legend

i = i+1; ax(i) = axes('Position', [0.1 0.08 0.2 0.171])   ; % ATM_ESC
xa = ax(i).Position(1) -0.07; ya = ax(i).Position(2) + ax(i).Position(4)+0.01;
annotation('textbox', [xa ya 0.01 0.01],'string', 'e', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle', ...
    'EdgeColor', 'none', 'FontSize', 14);

i = i+1; ax(i) = axes('Position', [0.41 0.08 0.2 0.171]); % FEP_ESC
xa = ax(i).Position(1) -0.07; ya = ax(i).Position(2) + ax(i).Position(4)+0.01;
annotation('textbox', [xa ya 0.01 0.01],'string', 'f', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle', ...
    'EdgeColor', 'none', 'FontSize', 14);

i = i+1; ax(i) = axes('Position', [0.72 0.08 0.14 0.171]); % add_drugs
xa = ax(i).Position(1) -0.09; ya = ax(i).Position(2) + ax(i).Position(4)+0.01;
annotation('textbox', [xa ya 0.01 0.01],'string', 'g', ...
    'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle', ...
    'EdgeColor', 'none', 'FontSize', 14);
end

function mage = load_mage(mp)
% loading the original mage struct
tmp = load([mp 'data_s2p2.mat'], 'mage');
mage_old(2) = tmp.mage;
tmp = load([mp 'data_s2p1.mat'], 'mage');
    mage_old(1) = tmp.mage;

load([ mp 'IC_struct']);
% constructing the mage IC_struct
mage.IC_struct = IC_struct;
mage.IC_mat = [IC_struct(1).IC_mat(1:end-1,:); IC_struct(2).IC_mat(1:end-1,:)];
mage.IC_wt = IC_struct(1).IC_mat(end,:);
mage.pos = [IC_struct(1).Pos(1:end-1); IC_struct(2).Pos(1:end-1)];
mage.mut_aa = [IC_struct(1).aa(1:end-1); IC_struct(2).aa(1:end-1)];

rel_pos = unique(cellfun(@(x) str2num(x(2:end)), mage.pos));
mage.orig_codon = [mage_old(1).orig_codons(any(mage_old(1).Pos == rel_pos'+16,2),:)
    mage_old(2).orig_codons(any(mage_old(2).Pos == rel_pos'+16,2),:)];
mage.all_aa = mage_old(1).aa';
mage.u_pos = unique(mage.pos, 'stable');
end

function plot_AB_AVI(mage, ax)
[col,symb] = ampc_markers;
for i = 1:3
    axes(ax(i)); axis square;
    x = mage.IC_mat(:,i*2-1);
    y = mage.IC_mat(:,i*2);
    l = [min([x(:); y(:)])/1.55 max([x(:); y(:)])*3.5];
    xlim(l); ylim(l);
    wtx = mage.IC_wt(i*2-1); wty = mage.IC_wt(i*2); 
    p = patch([wtx/1.55 wtx*1.55 wtx*1.55  wtx/1.55], ...
        [l(1) l(1) wtx*1.55  wtx/1.55], [0.9 0.9 0.9], 'edgecolor', 'none'); hold on;
    p = patch([wtx*1.55 wtx*1.55  l(2) l(2)], ...
        [wtx/1.55 wtx*1.55 wtx*1.55  wtx/1.55], [0.9 0.9 0.9], 'edgecolor', 'none');
    d = gscatter(x, y, mage.pos, col, symb, [], 0);

    plot(l, l, '-k', 'linewidth', 2);    
    plot(wtx, wty, 'xk', 'MarkerSize', 10, 'LineWidth', 2);
    plot([wtx wtx], [l(1), wtx], 'k--');
    plot([wtx l(2)], [wtx, wtx], 'k--');
    plot([wty l(2)], [wty wty], 'k--');

    xlabel(['IC50_{' mage.IC_struct(1).ab(i*2-1).Name '}^{Mut} (\mug/ml)']);
    ylabel(['IC50_{' mage.IC_struct(1).ab(i*2-1).Name '}^{Mut}|^{AVI} (\mug/ml)']);
    set(ax(i), 'XScale', 'log', 'YScale', 'log', 'XMinorTick', ...
        1, 'YMinorTick', 1, 'xtick', 10.^(-2:2), 'ytick', 10.^(-2:2), ...
        'XLim', l, 'YLim', l, 'box' ,'on');
    
    dist = (log10(l(2)/l(1)))^0.3;
    
    draw_arrow(ax(i), [l(2)*dist l(2)*dist], [wtx l(2)*0.95],'k');
    text(l(2)*dist^2.5, geomean([l(2), wtx*0.5]), 'Escape Mut.', 'Rotation', 90, 'HorizontalAlignment', 'center', 'fontsize', 8);
    
    if i == 2
        n = ismember(mage.pos, {'Y150'}) & mage.mut_aa == 'A';
        xy = mage.IC_mat(n, 3:4);
        text(xy(1)*0.9, xy(2)*0.6, 'Y150A', 'FontSize', 8, 'FontName', 'courier');
    end
    if i == 3
        n = ismember(mage.pos, {'N346'}) & mage.mut_aa == 'W';
        xy = mage.IC_mat(n, 5:6);
        text(xy(1)*1.2, xy(2)*1.4, 'N346W', 'FontSize', 8, 'FontName', 'courier');
    end
    
end

end    
    
function plot_schematics(ax)
axes(ax); axis square;
l = lines(7);
xlim([1 10]); ylim([1 10]); hold on;

% ab resistant
patch([5 10 10 5], [1 1 10 5], 'r', 'facecolor', l(2,:), 'facealpha', 0.4, 'edgecolor', 'none');

% comb resistant
xl = 1+(2.3:0.3:10);
plot([xl;10+zeros(size(xl))], [xl; xl], 'Color', [0.3 0.65 1], 'LineWidth', 1);

% escape Mut
yl = 5+(0.2:0.3:5);
plot([yl; yl], [5+zeros(size(yl)); yl], 'Color', l(7,:), 'LineWidth', 2);

%
axis square;
plot(1:10, 'k-', 'linewidth', 2);
plot(5,3,'kx', 'MarkerSize', 10, 'LineWidth',2);
plot([5 5], [1 5], 'k--', 'LineWidth',1.5);
plot([5 10], [5 5], 'k--', 'LineWidth',1.5);
plot([3 10], [3 3], 'k--', 'LineWidth',1.5);

xlabel('IC50_{AB}^{Mut}');
ylabel('IC50_{AB}^{Mut}|^{AVI}');
set(gca, 'XTick', 2:3:8, 'Xticklabel', {'10^{-1}' '10^{0}' '10^{1}'} , ...
    'YTick', 2:3:8, 'Yticklabel', {'10^{-1}' '10^{0}' '10^{1}'}, 'box', 'on');

% drawing legend
% resistant to combination
yb = 7.75;
patch([1.5 2.5 2.5 1.5], [yb yb yb+0.5 yb+0.5], 'k', 'facecolor', l(2,:), 'facealpha', 0.4);
text(2.7, yb+0.25, 'Res. to AB', 'FontSize', 8);

% resistant to the drug
xl = 1.7:0.3:2.4;
yb = repmat(9.25, size(xl));
patch([1.5 2.5 2.5 1.5], [yb(1) yb(1) yb(1)+0.5 yb(1)+0.5], 'k', 'facecolor', 'none');
plot([xl; xl], [yb; yb+0.5], 'Color', l(7,:), 'LineWidth', 1.5);
text(2.7, yb(1)+0.25, 'Escape mutants', 'FontSize', 8);

% resistance to combination
xl = [1.5 2.5];
yb = repmat(8.5, size(xl));
patch([1.5 2.5 2.5 1.5], [yb(1) yb(1) yb(1)+0.5 yb(1)+0.5], 'k', 'facecolor', 'none');
plot([xl; xl]', yb'+[0.15 0.35], 'Color', [0.3 0.65 1], 'LineWidth', 1);
text(2.7, yb(1)+0.25, 'Res. to comb.', 'FontSize', 8);

% add WT annotation
ar = draw_arrow(ax, [6.5 5.3], [2.2 2.9], 'k');
ar.LineWidth = 1.5;
ar.HeadLength = 6;
ar.HeadWidth = 7;
text(6.6, 2.2, 'WT');
% Escape mutation arrow
draw_arrow(gca, [10.3 10.3], [5 9.8], 'k');
text(10.9, 7, 'Escape Mut.', 'Rotation', 90, 'HorizontalAlignment', 'center', 'fontsize', 8)
end

function plot_legend(pos, ax)
axes(ax);
[col,symb] = ampc_markers;
d = gscatter(ones(1,numel(pos)), numel(pos):-1:1, pos, col, symb, [], 0); hold on;
for j = 1:19
    text(1.5, 20-j, pos(j), 'fontsize', 8);
end
xlim([0.5 3]);
set(ax,'Visible', 'off');
end

function plot_2d_AVI(od_data, ah)
axes(ah);
y = od_data.cx(2:end);
x = od_data.cy(2:end);
[xx, yy] = meshgrid(x,y);
plot(xx(:), yy(:), 'k.', 'markersize',2); hold on;
l = lines(7);
contour(x, y, smooth2a(od_data.n_od_wt',1), [0.5 0.5], 'k', 'linewidth', 2); hold on;
contour(x, y, smooth2a(od_data.n_od_mut',1), [0.5 0.5], 'color', l(2,:), 'linewidth', 2);
set(ah, 'XScale', 'log', 'YScale', 'log', ...
    'xtick', 10.^(-2:2), 'ytick', 10.^(-2:2));
ylabel(['[' od_data.ab '] (\mug/ml)']);
xlabel('[AVI] (\mug/ml)');

% add legend
p = ah.Position;
if strcmp(od_data.ab, 'ATM')
    p(1) = p(1)+p(3)*0.4; p(2) = p(2)+p(4)*0.32; p(3) = p(3)/3; p(4) = p(4)*0.25;
else
    p(1) = p(1)+p(3)*0.4; p(2) = p(2)+p(4)*0.73; p(3) = p(3)/3; p(4) = p(4)*0.25;
end
axl = axes('Position', p);
xlim([0 4]); ylim([0 1.5]); hold on;
plot([0 1], [1 1], '-', 'color', l(2,:), 'linewidth', 2);
text(1.2, 1, ['IC50_{' od_data.ab '}^{' od_data.mut '}'], ...
    'FontName', 'courier','fontsize', 8)
plot([0 1], [0 0], '-', 'color', 'k', 'linewidth', 2);
text(1.2, 0, ['IC50_{' od_data.ab '}^{WT}'], 'fontsize', 8,'FontName', 'courier')
set(axl, 'Visible', 'off');
end

function plot_add_ab(mp_new_ab, ah)

[od_data, ct] = ampc_fig_4_od_add_ab(mp_new_ab, 0);
l = [0 0 0; 0.5 0.5 0.5];
l2 = l([1 2 1 2], :);
symb = '^^^^';
l = lines(7);
ah.Visible = 'off';
axes(ah);
for i = 1:5
    p = ah.Position;
    
    p(2) = p(2)+(i-1)*0.045; p(4) = 0.01;
    ah2 = axes('Position', p); hold on;
    for j = 1:numel(od_data(i).strains)
        plot(ct{i}(j), 0.5 , symb(j), 'Color', l2(j,:), 'MarkerFaceColor', 1-(j<3)*(1-l2(j,:)), 'markersize', 6, 'linewidth', 2)
    end
    set(ah2, 'YColor', 'none', 'XTick', 10.^(-2:3),'XScale', 'log', 'ylim', [0 1], 'box', 'off');
    
    n = min(ct{i}); x = max(ct{i});
    if (x/n)<50
        mid = geomean([x,n]);    
        xlim([mid/7 mid*7]);
    else
        xlim([n/2 x*2]);
    end
    ylabel(od_data(i).name, 'Color', 'k', 'Visible', 'on', ...
        'Rotation', 0, 'VerticalAlignment', 'middle');
    ar = draw_arrow(ah2, [ct{i}(1), ct{i}(4)], [1.7, 1.7], l(4,:));
    ar.HeadWidth = 8;
end
xlabel(ah, '\eta_{AB}^{MAGE/WT} (\mug/ml)', 'visible', 1);

p = ah.Position;
a = axes('Position', [p(1)+p(3)+0.005 p(2)+p(4)/2 0.08 p(4)*0.4]);
for j = 1:4
    plot(1, j , symb(j), 'Color', l2(j,:), 'MarkerFaceColor', 1-(j<3)*(1-l2(j,:)), 'markersize', 7, 'linewidth', 2); hold on;
    text(1.5,j, od_data(1).strains(j).name, 'FontSize', 8)    
end
xlim([0.5 3]);
a.Visible = 'off';
end