% analyse 2D data for ampC paper
function ab_data = ampc_calc_2d(mp, plot_f)
if ~exist('plot_f', 'var'); plot_f = 0; end
dp = [mp '\OD\mut_2d\'];
xn = [dp '191219_escape_final2.xlsx'];
odn = [dp '191220_20191220_esc_mut_plasmids_d300.txt'];
[~, concs] = d300_import_conc2(xn);
od_all = cellfun(@(x) reshape(x', [],1), mat2cell(csvread(odn), 8*ones(16,1), 12), 'UniformOutput', 0);

ab_conc{1} = concs([1:192 192*2+1:192*3], 1:2)/1000;
ab_conc{2} = concs([192*4+1:192*5 192*6+1:192*7], [1 3])/1000;
%%
if plot_f; figure; end
ab_data = struct('ab', {'FEP', 'ATM'}, 'mut', {'N346W' 'Y150A'}, ...
    'cx', [], 'cy', [], 'od_wt', [], 'n_od_wt', [], 'od_mut', [], 'n_od_mut', []);
x = {'10^{-2}', '10^{-1}', '1', '10'};
for i = 2:-1:1    
    od_data{i} = cell2mat(od_all(8*(i-1)+[1 3;2 4;5 7;6 8]));
    ab_data(i).cx = unique(ab_conc{i}(ab_conc{i}(:,1)==0,2)); ab_data(i).cx(2) = ab_data(i).cx(2)*1.1;
    ab_data(i).cy = unique(ab_conc{i}(ab_conc{i}(:,2)==0,1));
    i0 = prod(ab_conc{i},2) ~= 0;
    i00 = find(all(ab_conc{i} == 0, 2));
    od0 = mean2(od_data{i}(i00,:));
    %plot WT
    ab_data(i).od_wt = griddata(log(ab_conc{i}(i0,2))', log(ab_conc{i}(i0, 1)), od_data{i}(i0,1), ...
        log(ab_data(i).cx(2:end))', log(ab_data(i).cy(2:end)));
    ab_data(i).n_od_wt = (ab_data(i).od_wt-0.04)/(od0-0.04);
    if plot_f
    subplot(2,2,i);
    imagesc(log10(ab_data(i).cx(2:end)), log10(ab_data(i).cy(2:end)), ab_data(i).od_wt, [0 0.68]); colormap gray; hold on;    
    contour(log10(ab_data(i).cx(2:end)), log10(ab_data(i).cy(2:end)), smooth2a(ab_data(i).n_od_wt,1),[0.5 0.5], 'r', 'LineWidth', 2)   
    set(gca, 'YDir', 'normal', 'ytick', -2:1, 'yticklabel', x, 'XTick', [], ...
        'xtick', -2:1, 'xticklabel', x);
    xlabel(['[' ab_data(i).ab '] (\mug/ml)']);
    ylabel('[AVI] (\mug/ml)');
    title('WT');
    if i == 2
        legend('50% growth', 'box', 'off', 'textcolor', 'r');
    end
    end
    % plot the mutant
    ab_data(i).od_mut = griddata(log(ab_conc{i}(i0,2))', log(ab_conc{i}(i0, 1)), od_data{i}(i0,2), ...
        log(ab_data(i).cx(2:end))', log(ab_data(i).cy(2:end)));
    ab_data(i).n_od_mut = (ab_data(i).od_mut-0.04)/(od0-0.04);
    if plot_f
    subplot(2,2,i+2);
    imagesc(log10(ab_data(i).cx(2:end)), log10(ab_data(i).cy(2:end)), ab_data(i).od_mut, [0 0.68]); colormap gray; hold on;    
    contour(log10(ab_data(i).cx(2:end)), log10(ab_data(i).cy(2:end)), smooth2a(ab_data(i).n_od_mut,1),[0.5 0.5], 'r', 'LineWidth', 2)
    set(gca, 'YDir', 'normal', 'ytick', -2:1, 'yticklabel', x, 'XTick', [], ...
        'xtick', -2:1, 'xticklabel', x);
    xlabel(['[' ab_data(i).ab '] (\mug/ml)']);
    ylabel('[AVI] (\mug/ml)');
    title(ab_data(i).mut);
    end
end
    
if plot_f
hcb = colorbar;
hcb.Position = [0.92 0.2 0.03 0.6];
hcb.Label.String = 'OD_{600}';
hcb.Label.Position = [0.6 0.73 0];
hcb.Label.Rotation = 0;

annotation('textbox',[0.03 1 0.01 0.01], 'String', 'a', 'EdgeColor', [1 1 1], 'FontSize', 14);
annotation('textbox',[0.03 0.55 0.01 0.01], 'String', 'b', 'EdgeColor', [1 1 1], 'FontSize', 14);
annotation('textbox',[0.47 1 0.01 0.01], 'String', 'c', 'EdgeColor', [1 1 1], 'FontSize', 14);
annotation('textbox',[0.47 0.55 0.01 0.01], 'String', 'd', 'EdgeColor', [1 1 1], 'FontSize', 14);

print ampc_supp7_2d -dpng -r600;
end