function [od_data, ct, fh] = ampc_fig_4_od_add_ab(mp, pc)

%% Initialize parameters
th = 0.1; %l = lines(7);
if ~exist('mp', 'var')
    mp = '/home/kishonylab/Dor/AmpC/robo_4_fig4/190618_Add_AB/';
end

if ~exist('pc', 'var')
    pc = 1;
end

%% analyse OD data
od_data = ana_od(mp);
%% prepare the axes of figures;
if pc
    fh = figure('Position', [100 100 450 300]);
    ax = open_axes;
else
    ax = ones(6,1);
end
%% plot Ni of bacteria VS conc.
ct = plot_ODi(od_data, th, ax, pc);
end
function od_data = ana_od(mp)

data_path = [mp 'data/'];
xls_name = dir([mp '*.xlsx']);
[~, strains] = xlsread([mp xls_name.name], 'Strains');
[~, ab_names] = xlsread([mp xls_name.name], 'AB');
c0 = xlsread([mp xls_name.name], 'Conc');

file_names = dir([data_path '*.xml']);
plate_names = cellfun(@(x) str2num(x{1}{1}), (regexp({file_names.name}, '(^\d.?)-', 'tokens')));
t0 = datevec(file_names(1).datenum);



for i = numel(strains):-1:1
    raw_data(i).ab = struct('name', ab_names);
    for k = numel(ab_names):-1:1
        raw_data(i).ab(k).conc = c0(k)./2.^(15:-1:0);
    end
    rel_p = find(plate_names == (i+10));
    raw_data(i).t = zeros(numel(rel_p),1);
    for j = 1:numel(rel_p)
        raw_data(i).t(j) = etime(datevec(file_names(rel_p(j)).datenum),t0)/60;
        od2 = d300_xml_parse([data_path file_names(rel_p(j)).name])';
        if ~mod(j,2)
            od2 = od2(end:-1:1, end:-1:1);
        end
        od = [od2(:,2:6); od2(:,7:11)]';
        for k = 1:numel(ab_names)
            raw_data(i).ab(k).od(j,:) = od(k,end:-1:1);
        end
    end
end

v = [2 6 1 5; 4 8 3 7];
strains = {'WT' 'MAGE' 'WT+AVI', 'MAGE+AVI'};

od_data = struct('name', {raw_data(1).ab.name}, 'conc', {raw_data(1).ab.conc});
for i = 1:numel(od_data)
    for j = 1:numel(strains)
        od_data(i).strains(j).name = strains{j};
        od_data(i).strains(j).od = cat(3, raw_data(v(1,j)).ab(i).od, raw_data(v(2,j)).ab(i).od);
        od_data(i).strains(j).t = cat(3, raw_data(v(1,j)).t, raw_data(v(2,j)).t);
    end
end
end


function ct = plot_ODi(od_data, th, ax, pc)

% ploting the curves
l = [0 0 0; 0.5 0.5 0.5];
lt = {'-' '-' '--' '--'};
l2 = l([1 2 1 2], :);
symb = '^o^o';
for i = 1:numel(od_data)
    ct{i} = plot_Ni_bact_from_od (od_data(i), ax(i), th,i);
    if pc
        if i == 1 || i == 4
            set(ax(i), 'ytick', 10.^[-8 -4 0]);
        else
            set(ax(i), 'ytick', []);
        end
    end
end

if pc
    % add legend
    axes(ax(6));
    for i = 1:4
        plot(1:2, [i i], lt{i}, 'color', l2(i,:),'linewidth', 2); hold on;
        plot(1.5, i, symb(i), 'Color', l2(i,:), 'MarkerFaceColor', 1-(i<3)*(1-l2(i,:)), 'markersize', 3);
        text(2.5, i, od_data(1).strains(i).name, 'FontSize', 8);
    end
    xlim([1 5]);
    ylim([-3 5]);
    ax(6).Visible = 'off';
    axl.YDir = 'reverse';
    % add general xlabel
    ax_yl = axes('position', [0.04 0 0.5 1]);
    text(0,  0.5, 'Initial density (viable mutants),\newline    {\itOD^0_{Mut} = OD_{th} /exp(g\cdott_{th} )}', ...
        'Rotation', 90, 'HorizontalAlignment', 'center', 'FontSize', 9)
    ax_yl.Visible = 'off';
end
    function ct = plot_Ni_bact_from_od (od_data, ah, th,i)
        %
        th_single = 3.3e-8;
        th_mat = od_data.conc';
        for j = 1:numel(od_data.strains)
            clear t_th t_th_rep;
            t = (od_data.strains(j).t(1:end-1,:,:)+od_data.strains(j).t(2:end,:,:))/2;
            od1 = od_data.strains(j).od-0.042; od1(od1<0) = 0;
            od = (od1(1:end-1,:,:) + od1(2:end,:,:))/2;
            
            for ci = size(od,2):-1:1
                rel_od = squeeze(od(:,ci,:)); rel_od(rel_od<=0) = 1e-4;
                rel_t = squeeze(t);
                for rep = 2:-1:1
                    i0 = find(smooth(rel_od(:,rep)-th<0,4), 1, 'last');
                    ind = i0-2:min(i0+1, size(rel_od,1));
                    t_th_rep(ci,rep) = interp1(rel_od(ind,rep)+rand(size(ind'))*1e-5, rel_t(ind,rep), th);
                end
                i0 = find(smooth(mean(rel_od,2)-th<0,4), 1, 'last');
                ind = i0-2:min(i0+1, size(rel_od,1));
                t_th(ci) = interp1(mean(rel_od(ind,:),2)+rand(size(ind'))*1e-5 , mean(rel_t(ind,:),2) , th);
            end
            th_mat = [th_mat (th*2.^(-0.026*t_th_rep))];
            %% fit to 2 stairs:
            
            th_rep_s = sort(t_th_rep,2);
            
            ind_nan = find(~any(isnan(t_th_rep),2));
            if numel(ind_nan)>4
                ft = fittype('-((15 * b)./(1+(c./x).^d) + (15*(1-b))./(1+(e./x).^f)+6)');
                ic0_1 = od_data.conc(find(th*2.^(-0.026*t_th) < 0.01 * th*2.^(-0.026*t_th(1)),1));
                ic0_2 = od_data.conc(find(th*2.^(-0.026*t_th) < 0.001 * th*2.^(-0.026*t_th(1)),1));
                fo = fitoptions(ft);
                fo.Startpoint = [0.5, ic0_1, 1, ic0_2, 1];
                fo.Lower = [0, 0, 0, 0, 0];
                fo.Upper = [1, inf, 20, inf, 20];
                
                
%                 semilogx(repmat(od_data.conc(ind_nan)',2,1), ...
%                     log(th*2.^(-0.026* reshape(t_th_rep(ind_nan,:), [],1) )), ...
%                     '.');
                f = fit(repmat(od_data.conc(ind_nan)',2,1), ...
                    log(th*2.^(-0.026* reshape(t_th_rep(ind_nan,:), [],1) )), ft, fo);
                xax = logspace(log10(od_data.conc(find(ind_nan,1))), log10(od_data.conc(2+find(ind_nan,1, 'last'))), 1000);
%                 hold on;
%                 plot(xax, f(xax), '-'); hold off;
                
                if pc
                    axes(ah);
                    loglog(xax, exp(f(xax)) ...
                        , lt{j}, 'Color', l2(j,:), 'LineWidth',2); hold on;
                end
            else
                f = fit(od_data.conc(ind_nan)', ...
                    log(th*2.^(-0.026* mean(t_th_rep(ind_nan,:),2))), 'linearinterp');
                if pc
                    axes(ah);
                    xax = logspace(log10(od_data.conc(1)), log10(od_data.conc(find(ind_nan,1,'last')+1)));
                    loglog(ah, xax, exp(f(xax)), lt{j}, 'Color', l2(j,:), 'LineWidth',2); hold on;
                end
            end
            
%             x0 = fminbnd(f, od_data.conc(1), od_data.conc(end));
            ct(j) = fzero(@(x) exp(f(x))-th_single, [od_data.conc(1) od_data.conc(end)]);
            if pc
                semilogx( od_data.conc, (th*2.^(-0.026*th_rep_s)), symb(j), 'Color', l2(j,:), 'MarkerFaceColor', 1-(j<3)*(1-l2(j,:)), 'markersize', 3);
            end
        end
%         writematrix(th_mat, 'aa.xlsx', 'Sheet', i);
        if pc
            plot(xlim, [th_single th_single], '--k');
            ylim([1e-9 0.01])
            set(ah, 'XTick', 10.^(-2:2));
            xlabel(['[' od_data.name '] \mug/ml'])
        end
    end
end


function ax = open_axes
for i = 1:6
    ax(i) = subplot(2, 3,  i);
end
end